@@ -1,4 +1,4 @@
-### $Id: simulate.R,v 1.4 2001/03/30 16:50:52 bates Exp $
+### $Id: simulate.R,v 1.6 2002/01/27 23:27:10 bates Exp $
 ###
 ###            Fit a general linear mixed effects model
 ###
@@ -21,7 +21,7 @@
 ### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
 ### MA 02111-1307, USA
 
-"createConLin"<-
+createConLin <-
   function(fixed, data = sys.frame(sys.parent()),
 	   random = pdSymm(eval(as.call(fixed[-2]))), ...)
 {
@@ -501,9 +501,9 @@ plot.simulate.lme <-
     }
   }
   xyplot(form, data = frm,
-	 panel = function(x, y) {
-           panel.grid();
-           panel.xyplot(x, y, type = "l")
+	 panel = function(x, y, ...) {
+           panel.grid()
+           panel.xyplot(x, y, type = "l", ...)
            if ((dfType <- as.double(names(x)[1])) == 1) {
              panel.abline( 0, as.double(names(x)[1]), lty = 2 )
            } else {
